piecash.sa_extra module — Python interface to GnuCash documents 0.14.1 documentation

# piecash.sa_extra module

`piecash.sa_extra.` `compile_datetime`(element, compiler, **kw)

  data type for the date field

  note: it went from TEXT(14) in 2.6 to TEXT(19) in 2.8 to accommodate for the new ISO format of date in sqlite

`piecash.sa_extra.` `mapped_to_slot_property`(col, slot_name, slot_transform=<function <lambda>>)

  Assume the attribute in the class as the same name as the table column with “_” prepended

`piecash.sa_extra.` `pure_slot_property`(slot_name, slot_transform=<function <lambda>>, ignore_invalid_slot=False)

  Create a property (class must have slots) that maps to a slot

  Parameters: | slot_name – name of the slot slot_transform – transformation to operate before assigning value ignore_invalid_slot – True if incorrect values (usually due to deleted data) should be converted to None
  Returns: |

`piecash.sa_extra.` `get_foreign_keys`(metadata, engine)

  Retrieve all foreign keys from metadata bound to an engine :param metadata: :param engine: :return: